==> jc-1.4.0.tar.gz: soot/jimple/parser/node/PBaseTypeNoName.h <==
// public abstract class soot.jimple.parser.node.PBaseTypeNoName

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class cf55e2dd32eddb45 soot_jimple_parser_node_PBaseTypeNoName

// header file dependencies
// @dep_header soot_jimple_parser_node_Node

#include "soot/jimple/parser/node/Node.h"

#ifndef _JC_soot_jimple_parser_node_PBaseTypeNoName_H_
#define _JC_soot_jimple_parser_node_PBaseTypeNoName_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_PBaseTypeNoName$sub_refs	_jc_soot_jimple_parser_node_PBaseTypeNoName$sub_refs;
typedef struct _jc_soot_jimple_parser_node_PBaseTypeNoName$sub_nonrefs	_jc_soot_jimple_parser_node_PBaseTypeNoName$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_PBaseTypeNoName$refs	_jc_soot_jimple_parser_node_PBaseTypeNoName$refs;
typedef struct _jc_soot_jimple_parser_node_PBaseTypeNoName$nonrefs	_jc_soot_jimple_parser_node_PBaseTypeNoName$nonrefs;
typedef struct _jc_soot_jimple_parser_node_PBaseTypeNoName$object	_jc_soot_jimple_parser_node_PBaseTypeNoName$object;

typedef const struct _jc_soot_jimple_parser_node_PBaseTypeNoName$vmethods	_jc_soot_jimple_parser_node_PBaseTypeNoName$vmethods;
typedef const struct _jc_soot_jimple_parser_node_PBaseTypeNoName$vtable	_jc_soot_jimple_parser_node_PBaseTypeNoName$vtable;
typedef const struct _jc_soot_jimple_parser_node_PBaseTypeNoName$vtype	_jc_soot_jimple_parser_node_PBaseTypeNoName$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_PBaseTypeNoName$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_PBaseTypeNoName$object *);

// Virtual methods structure
struct _jc_soot_jimple_parser_node_PBaseTypeNoName$vmethods {
};

// Vtable
struct _jc_soot_jimple_parser_node_PBaseTypeNoName$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PBaseTypeNoName$vmethods	soot_jimple_parser_node_PBaseTypeNoName;
};

// Vtype
struct _jc_soot_jimple_parser_node_PBaseTypeNoName$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_PBaseTypeNoName$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_PBaseTypeNoName$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_PBaseTypeNoName$refs {
    _jc_soot_jimple_parser_node_PBaseTypeNoName$sub_refs	soot_jimple_parser_node_PBaseTypeNoName;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_PBaseTypeNoName$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_PBaseTypeNoName$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PBaseTypeNoName$sub_nonrefs	soot_jimple_parser_node_PBaseTypeNoName;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_PBaseTypeNoName$object {
	_jc_soot_jimple_parser_node_PBaseTypeNoName$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_PBaseTypeNoName$vtype	*vtype;
	_jc_soot_jimple_parser_node_PBaseTypeNoName$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_PBaseTypeNoName$vtype _jc_soot_jimple_parser_node_PBaseTypeNoName$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_PBaseTypeNoName, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_PBaseTypeNoName$class_object;

#endif	/* _JC_soot_jimple_parser_node_PBaseTypeNoName_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/parser/node/PBaseTypeNoName.h <==
// public abstract class soot.jimple.parser.node.PBaseTypeNoName

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class cf55e2dd32eddb45 soot_jimple_parser_node_PBaseTypeNoName

// header file dependencies
// @dep_header soot_jimple_parser_node_Node

#include "soot/jimple/parser/node/Node.h"

#ifndef _JC_soot_jimple_parser_node_PBaseTypeNoName_H_
#define _JC_soot_jimple_parser_node_PBaseTypeNoName_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_PBaseTypeNoName$sub_refs	_jc_soot_jimple_parser_node_PBaseTypeNoName$sub_refs;
typedef struct _jc_soot_jimple_parser_node_PBaseTypeNoName$sub_nonrefs	_jc_soot_jimple_parser_node_PBaseTypeNoName$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_PBaseTypeNoName$refs	_jc_soot_jimple_parser_node_PBaseTypeNoName$refs;
typedef struct _jc_soot_jimple_parser_node_PBaseTypeNoName$nonrefs	_jc_soot_jimple_parser_node_PBaseTypeNoName$nonrefs;
typedef struct _jc_soot_jimple_parser_node_PBaseTypeNoName$object	_jc_soot_jimple_parser_node_PBaseTypeNoName$object;

typedef const struct _jc_soot_jimple_parser_node_PBaseTypeNoName$vmethods	_jc_soot_jimple_parser_node_PBaseTypeNoName$vmethods;
typedef const struct _jc_soot_jimple_parser_node_PBaseTypeNoName$vtable	_jc_soot_jimple_parser_node_PBaseTypeNoName$vtable;
typedef const struct _jc_soot_jimple_parser_node_PBaseTypeNoName$vtype	_jc_soot_jimple_parser_node_PBaseTypeNoName$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_PBaseTypeNoName$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_PBaseTypeNoName$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_PBaseTypeNoName$vmethods {
};

// Vtable
struct _jc_soot_jimple_parser_node_PBaseTypeNoName$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PBaseTypeNoName$vmethods	soot_jimple_parser_node_PBaseTypeNoName;
};

// Vtype
struct _jc_soot_jimple_parser_node_PBaseTypeNoName$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_PBaseTypeNoName$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_PBaseTypeNoName$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_PBaseTypeNoName$refs {
    _jc_soot_jimple_parser_node_PBaseTypeNoName$sub_refs	soot_jimple_parser_node_PBaseTypeNoName;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_PBaseTypeNoName$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_PBaseTypeNoName$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PBaseTypeNoName$sub_nonrefs	soot_jimple_parser_node_PBaseTypeNoName;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_PBaseTypeNoName$object {
	_jc_soot_jimple_parser_node_PBaseTypeNoName$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_PBaseTypeNoName$vtype	*vtype;
	_jc_soot_jimple_parser_node_PBaseTypeNoName$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_PBaseTypeNoName$vtype _jc_soot_jimple_parser_node_PBaseTypeNoName$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_PBaseTypeNoName, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_PBaseTypeNoName$class_object;

#endif	/* _JC_soot_jimple_parser_node_PBaseTypeNoName_H_ */
